/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonClassMetadata.java 2950 2008-04-25 09:14:23Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.scan.api.metadata.ClassMetadata;
import org.ow2.util.scan.api.metadata.structures.JClass;

/**
 * EZB common class metadata.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonClassMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ClassMetadata<C, M, F> implements ICommonClassMetadata<C, M, F> {

    /**
     * metadata common with class, field and method.
     */
    private CommonMetadata ejbJarCommonMetadata;

    /**
     * Object representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    private List<IJEjbEJB> jEjbEJBs = null;

    /**
     * Object representing &#64;{@link javax.annotation.Resources} annotation.
     */
    private List<IJAnnotationResource> jAnnotationResources = null;

    /**
     * Object representing &#64;{@link javax.persistence.PersistenceContext} annotation.
     */
    private List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts = null;

    /**
     * Object representing &#64;{@link javax.persistence.PersistenceUnit} annotation.
     */
    private List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits = null;

    /**
     * Constructor.
     * @param jClass signature
     */
    public CommonClassMetadata(final JClass jClass) {
        super(jClass);
        this.ejbJarCommonMetadata = new CommonMetadata();
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final IJEjbEJB getJEjbEJB() {
        return this.ejbJarCommonMetadata.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.ejbJarCommonMetadata.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final IJAnnotationResource getJAnnotationResource() {
        return this.ejbJarCommonMetadata.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.ejbJarCommonMetadata.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.ejbJarCommonMetadata.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return this.ejbJarCommonMetadata.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.ejbJarCommonMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.ejbJarCommonMetadata.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.ejbJarCommonMetadata.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.ejbJarCommonMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    public final List<IJEjbEJB> getJEjbEJBs() {
        return this.jEjbEJBs;
    }

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    public final void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs) {
        this.jEjbEJBs = jEjbEJBs;
    }

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    public final List<IJAnnotationResource> getJAnnotationResources() {
        return this.jAnnotationResources;
    }

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    public final void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources) {
        this.jAnnotationResources = jAnnotationResources;
    }

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    public final List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return this.javaxPersistencePersistenceContexts;
    }

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    public final void setJavaxPersistencePersistenceContexts(
            final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        this.javaxPersistencePersistenceContexts = javaxPersistencePersistenceContexts;
    }

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return this.javaxPersistencePersistenceUnits;
    }

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        this.javaxPersistencePersistenceUnits = javaxPersistencePersistenceUnits;
    }

}
